#ifndef CACHEDFRAME_H		// -*- c++ -*-
#define CACHEDFRAME_H
///
// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
///
#include "basicframe.h"
#include <sigc++/slot.h>

class CachedFrame: public BasicFrame {
public:
  CachedFrame(Group *parent, const std::string &name);
  CachedFrame(const ElementWrap& xml, Group *parent);
  
  virtual void generate_picture(std::ostream& psstream) const = 0;
  
protected:
  bool white_is_transparent; // fake transparency
};

#endif
